package com.atlassian.clover.api.instrumentation;

import com.atlassian.clover.api.registry.ClassInfo;
import com.atlassian.clover.api.registry.FileInfo;
import com.atlassian.clover.api.registry.MethodInfo;
import com.atlassian.clover.api.registry.PackageInfo;
import com.atlassian.clover.api.registry.SourceInfo;
import com.atlassian.clover.spi.lang.LanguageConstruct;
import com.cenqua.clover.context.ContextSet;
import com.cenqua.clover.registry.BranchInfo;
import com.cenqua.clover.registry.MethodSignature;
import com.cenqua.clover.registry.StatementInfo;

import java.io.File;

public interface InstrumentationSession {
    PackageInfo enterPackage(String name);
    void exitPackage();

    FileInfo enterFile(
        String packageName, File file, int lineCount, int ncLineCount,
        long timestamp, long filesize, long checksum);
    void exitFile();

    ClassInfo enterClass(
        String name, SourceInfo region, boolean isInterface,
        boolean isEnum, boolean isAnnotation);
    ClassInfo exitClass(int endLine, int endCol);

    MethodInfo enterMethod(ContextSet context, SourceInfo region, MethodSignature signature, boolean test, int complexity, LanguageConstruct construct);
    void exitMethod(int endLine, int endCol);

    StatementInfo addStatement(ContextSet context, SourceInfo region, int complexity, LanguageConstruct construct);
    BranchInfo addBranch(ContextSet context, SourceInfo region, boolean instrumented, int complexity, LanguageConstruct construct);

    void setSourceEncoding(String encoding);

    int getCurrentIndex();
    int getCurrentFileMaxIndex();
    int getCurrentOffsetFromFile();

    long getStartTs();
    long getEndTS();
    long getVersion();

    FileInfo getCurrentFile();
    PackageInfo getCurrentPackage();
    ClassInfo getCurrentClass();
    MethodInfo getCurrentMethod();

    void close() throws ConcurrentInstrumentationException;
}
